(function () {
  'use strict';

  /**
   * @typedef {Object} AccountAndWorkspace
   * @property {string} workspace - Current IO workspace
   * @property {string} account - Current IO account
   */

  /**
   * Gets the account and workspace in which this
   * script is running on top of.
   *
   * @returns {AccountAndWorkspace} The account and workspace in which this script is running on top of.
   */
  function getAccountAndWorkspace() {
    const [workspace, account] = window.location.host
      .replace(".vtexcommercestable.com.br", "")
      .replace(".vtexcommercebeta.com.br", "")
      .split("--");

    if (!account) {
      return { workspace: "master", account: workspace };
    }

    return { workspace, account };
  }

  /**
   * Whether or not the script is running inside an
   * iframe.
   *
   * @returns boolean
   */
  const isWithinIframe = (function isIframe() {
    return window.self !== window.top;
  })();

  const inContextScript = `var _jipt = [];
_jipt.push(['project', 'admin-home']);`;

  const CRWDIN_IN_CONTEXT_ID = "crowdin-in-context-legacy-id--DoUbNU";
  const CRWDIN_IN_CONTEXT_SRC_ID = "crowdin-in-context-src-legacy-id--DoUbNU";
  const CRWDIN_IN_CONTEXT_WORKSPACE = "acholi";
  const CRWDIN_IN_CONTEXT_ACCOUNT = "storecomponents";

  /**
   * Prepares the Crowdin In Context
   * initialization.
   *
   * @returns void
   */
  function prepareCrowdinInContext() {
    if (!document.getElementById(CRWDIN_IN_CONTEXT_ID)) {
      const script = document.createElement("script");
      script.id = CRWDIN_IN_CONTEXT_ID;
      script.type = "text/javascript";
      script.innerText = inContextScript;
      document.body.appendChild(script);
    }
  }

  /**
   * Loads the Crowdin In Context
   * script.
   *
   * @returns void
   */
  function loadCrowdinInContext() {
    if (!document.getElementById(CRWDIN_IN_CONTEXT_SRC_ID)) {
      const script = document.createElement("script");
      script.id = CRWDIN_IN_CONTEXT_SRC_ID;
      script.type = "text/javascript";
      script.src = "//cdn.crowdin.com/jipt/jipt.js";
      document.body.appendChild(script);
    }
  }

  /**
   * Checks whether or not the script
   * is running on the localization
   * workspace.
   *
   * @returns boolean
   */
  function shouldInjectCrowdinInContext() {
    if (!isWithinIframe) {
      return false;
    }

    const { account, workspace } = getAccountAndWorkspace();

    if (
      workspace === CRWDIN_IN_CONTEXT_WORKSPACE &&
      account === CRWDIN_IN_CONTEXT_ACCOUNT
    ) {
      return true;
    }

    return false;
  }

  /**
   * Injects the Crowdin In-Context script
   * on the legacy applications within the
   * Admin.
   *
   * @returns void
   */
  function startCrowdinInContext() {
    if (shouldInjectCrowdinInContext()) {
      prepareCrowdinInContext();
      loadCrowdinInContext();
    }
  }

  function addVtexLoaderScript() {
    const vtexLoaderScript = document.createElement("script");
    vtexLoaderScript.async = false;
    vtexLoaderScript.src =
      "//io.vtex.com.br/io-vtex-loader/2.3.1/io-vtex-loader.min.js";
    document.body.appendChild(vtexLoaderScript);
  }

  console.debug(
    `%c [ADMIN CMS JS] - Running custom js `,
    "background: #002833; color: #258bd2"
  );

  /*************************************************
   *   THIS BLOCK RUNS ONLY WHEN INSIDE AN IFRAME   *
   **************************************************/

  if (isWithinIframe) {
    console.debug(
      `%c [ADMIN CMS JS] - running inside iframe`,
      "background: #002833; color: #258bd2"
    );
    $("#btnVoltar").hide(); // botao que volta pro catálogo (ñ faz sentido no)
    $(".tool-box").hide();
    // adjust height of code editor
    setInterval(() => {
      if ($("#editor")[0] && $("#editor").height() !== 450) {
        console.debug(
          `%c [ADMIN CMS JS] - adjusting editor height`,
          "background: #002833; color: #258bd2"
        );
        if ($("#editor")[0] && $("#editor")[0].style) {
          $("#editor")[0].style.height = "450px;";
        }
        var contentHeight = $(".ace_content").height();
        if ($(".ace_scroller")[0] && $(".ace_scroller")[0].style) {
          $(".ace_scroller")[0].style.height = `${contentHeight}px`;
        }
      }
      const uiWidgets = $(
        ".ui-dialog.ui-widget.ui-widget-content.ui-corner-all.ui-draggable.ui-resizable.ui-dialog-buttons"
      );
      if (uiWidgets && uiWidgets.length > 0) {
        uiWidgets.each((index, el) => {
          if (
            el.style["display"] === "block" &&
            el.style.position &&
            el.style.top
          ) {
            console.debug(
              `%c [ADMIN CMS JS] - adjusting dialog box widget`,
              "background: #002833; color: #258bd2"
            );
            // ajusta posiçao da caixa de dialogo qnd ela aparece por algum motivo com "top: -900px" e relativa
            el.style.position = null;
            el.style.top = null;
          }
        });
      }
    }, 500);

    startCrowdinInContext();
  }

  /***************************************************
   *  THIS BLOCK RUNS ONLY WHEN NOT INSIDE AN IFRAME  *
   ****************************************************/

  if (!isWithinIframe) {
    console.debug(
      `%c [ADMIN CMS JS] - NOT running inside iframe`,
      "background: #002833; color: #258bd2"
    );
    // legacy topbar load
    addVtexLoaderScript();
    $(window).on("topbarLoaded.vtex", function () {
      vtex.topbar.topbar = new vtex.topbar.Topbar();
    });
  }

}());
